<?php

// Localisation
load_theme_textdomain('tarski');

$themeData = get_theme_data(TEMPLATEPATH . '/style.css');
$installedVersion = $themeData['Version'];
if(!$installedVersion) {
	$installedVersion = "unknown";
}

$highlightColor = "#a3c5cc";

add_action('admin_head', 'inject_tarski_js');
add_action('activity_box_end', 'update_dashboard');
add_action('simple_edit_form', 'tarski_classesnote', 1);
add_action('edit_form_advanced', 'tarski_classesnote', 1);

function tarski_classesnote() {
	echo "<fieldset id=\"tarskiclasses\" class=\"dbx-box\"><h3 class=\"dbx-handle\">"; _e('Tarski Classes', 'tarski'); echo "</h3><div class=\"dbx-content\">\n";
	echo "<p>"; _e('<a href="http://tarskitheme.com/">Tarski</a> comes with a number of helpful <acronym title="Cascading Stylesheets">CSS</acronym> classes for formatting and positioning your post contents.', 'tarski'); echo "  <a href=\"http://tarskitheme.com/help/styling/\">"; _e('Read more here &raquo;', 'tarski'); echo "</a>"; echo "</p>\n";
	echo "</div></fieldset>\n";
}

// widgets!
if(function_exists('register_sidebar')) {
	register_sidebar(array(
		'name' => 'Main Sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>'
	));
	register_sidebar(array(
		'name' => 'Footer Widgets',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>'
	));
}

function update_dashboard() {
	global $installedVersion;
	
	echo "<h3>Tarski Updates</h3>\n";
	if(get_option('tarski_update_notification') == 'true') {
		echo "<script src=\"http://tarskitheme.com/version.php?version=$installedVersion&verbose=true\" type=\"text/javascript\"></script>\n";
	} else {
		echo "<p>Update notification for the Tarski theme <a href=\"themes.php?page=functions.php\">is currently turned off</a>.</p>";
	}
}

$count_users = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->usermeta WHERE `meta_key` = '" . $table_prefix . "user_level' AND `meta_value` > 1");
	if ($count_users > 1) { $multipleAuthors = 1; }

function link_pages_without_spaces() {
	ob_start();
	link_pages('<p class="pagelinks"><strong>Pages</strong>', '</p>', 'number', '', '', '%', '');
	$text = ob_get_contents();
	ob_end_clean();
	
	$text = str_replace(' <a href', '<a href', $text);
	$text = str_replace('> ', '>', $text);
	echo $text;
}

function tarski_title($type = 'title') {
	$titleSep = '&middot;';
	// tarski_title('header') is for use within the document <body>
	if ($type == 'header') {
		if(is_home()) { echo '<h1 id="blog-title">' . get_bloginfo('name') . '</h1>'; }
		else { echo '<p id="blog-title"><a title="Return to front page" href="' . get_settings('home') . '">' . get_bloginfo('name') . '</a></p>'; }
	}
	// tarski_title() is for use within the document <title>
	else { echo get_bloginfo('name');
		if (is_home()) { if (get_bloginfo('description') != '') { echo ' ' . $titleSep . ' ' . get_bloginfo('description'); } }
		elseif (is_search()) { echo ' ' . $titleSep . ' Search results'; }
		elseif (is_month()) { echo ' ' . $titleSep . ' '; single_month_title(' '); }
		else { wp_title($titleSep); }
	}
}

function inject_tarski_js() {
	echo '<script src="' . get_bloginfo('template_directory') . '/js/prototype.js' .'" type="text/javascript"></script>';
	echo '<script src="' . get_bloginfo('template_directory') . '/js/scriptaculous.js' .'" type="text/javascript"></script>';
	echo '<script src="' . get_bloginfo('template_directory') . '/js/tarski.js' .'" type="text/javascript"></script>';
}

function tarskiupdate() {
	global $wpdb, $user_ID;
	get_currentuserinfo();
	
	if ( !empty($_POST) ) {
		if($_POST['tarski_update_notification'] == 'Turn update notification off?') {
			update_option('tarski_update_notification', 'false');
		}	elseif($_POST['tarski_update_notification'] == 'Turn update notification on?') {
			update_option('tarski_update_notification', 'true');
		}
		
		if (isset($_POST['about_text'])) {
			$about = $_POST['about_text'];
			update_option('blurb', $about, '','');
		}
		if (isset($_POST['header_image'])) {
			$header = $_POST['header_image'];
			$header = @str_replace("-thumb", "", $header);
			update_option('tarski_header', $header, '','');
		}
		
		update_option('tarski_sidebar_pages', $_POST['sidebar']['pages']);
		update_option('tarski_sidebar_links', $_POST['sidebar']['links']);
		update_option('tarski_sidebar_comments', $_POST['sidebar']['comments']);
		update_option('tarski_sidebar_custom', $_POST['sidebar']['custom']);
		update_option('tarski_sidebar_onlyhome', $_POST['sidebar']['onlyhome']);
		
		update_option('tarski_display_title', $_POST['display_title']);
		update_option('tarski_display_tagline', $_POST['display_tagline']);
		update_option('tarski_hide_categories', $_POST['hide_categories']);
		update_option('tarski_use_pages', $_POST['use_pages']);
		update_option('tarski_centered_theme', $_POST['centered_theme']);
		update_option('tarski_swap_sides', $_POST['swap_sides']);
		update_option('tarski_asidescategory', $_POST['asides_category']);
		update_option('tarski_style', $_POST['alternate_style']);
		update_option('tarski_ajax_tags', $_POST['ajax_tags']);
		
		update_option('tarski_nav_pages', implode(',', $_POST['nav_pages']));
		
		if(in_array('about', $_POST['create_page'])) {
			if(!tarski_checkForStaticPage('About')) {
				tarski_createStaticPage('About', '', 'static.php');
			}
		}
		
		if(in_array('archives', $_POST['create_page'])) {
			if(!tarski_checkForStaticPage('Archives')) {
				tarski_createStaticPage('Archives', '', 'archives.php');
			}
		}
		
		if(in_array('tags', $_POST['create_page'])) {
			if(!tarski_checkForStaticPage('Tags')) {
				tarski_createStaticPage('Tags', '', 'tags.php');
			}
		}
	}
}

function tarski_checkForStaticPage($title) {
	global $wpdb, $user_ID;
	get_currentuserinfo();
	
	$query = "SELECT ID FROM $wpdb->posts WHERE post_title='$title' AND post_status='static'";
	$result = $wpdb->query($query);
	
	if($result > 0) {
		return true;
	} else {
		return false;
	}
}

function tarski_createStaticPage($post_title, $content, $template) {
	global $wpdb, $user_ID;
	get_currentuserinfo();
	
	$now = current_time('mysql');
	$now_gmt = current_time('mysql', 1);
	$post_author = $user_ID;
	$id_result = $wpdb->get_row("SHOW TABLE STATUS LIKE '$wpdb->posts'");
	$post_ID = $id_result->Auto_increment;
	$post_name = sanitize_title($post_title, $post_ID);
	$ping_status = get_option('default_ping_status');
	$comment_status = get_option('default_comment_status');
	
	$postquery ="INSERT INTO $wpdb->posts (ID, post_author, post_date, post_date_gmt, post_content, post_title, post_excerpt,  post_status, comment_status, ping_status, post_password, post_name, to_ping, post_modified, post_modified_gmt, post_parent, menu_order) VALUES ('$post_ID', '$post_author', '$now', '$now_gmt', '$content', '$post_title', '', 'static', '$comment_status', '$ping_status', '', '$post_name', '', '$now', '$now_gmt', '', '')";
	$result = $wpdb->query($postquery);
	
	$metaquery = "INSERT INTO $wpdb->postmeta(meta_id, post_id, meta_key, meta_value) VALUES('', '$post_ID', '_wp_page_template', '$template')";
	$result2 = $wpdb->query($metaquery);
}

// if we can't find Tarski installed let's go ahead and install all the options that run Tarski.  This should run only one more time for all our existing users, then they will just be getting the upgrade function if it exists.

if (!get_option('tarski_installed')) {
	add_option('tarski_installed', $installedVersion, 'This options simply tells us if Tarski has been installed before', $autoload);
	add_option('tarski_header', 'greytree.jpg', '', $autoload);
	add_option('blurb', 'This is the about text', 'Allows you to write a small blurb about you and your blog, which will be put on the frontpage', $autoload);
}

// Here we handle upgrading our users with new options and such.  If tarski_installed is in the DB but the version they are running is lower than our current version, trigger this event.

elseif (get_option('tarski_installed') < $installedVersion) {
	if(get_option('tarski_installed') < 1.1) {
		add_option('tarski_asidescategory', '0', 'ID of a category to display as Asides.');
	}
	update_option('tarski_installed', $installedVersion);
}

// This adds the Tarski Options page
add_action ('admin_menu', 'tarskimenu');

$tloc = '../themes/' . basename(dirname($file)); 

function tarskimenu() {
	add_submenu_page('themes.php', 'Tarski Options', 'Tarski Options', 5, $tloc . 'functions.php', 'menu');
}

function menu() {
	global $installedVersion, $highlightColor;
	
	load_plugin_textdomain('tarskioptions');
	// Tarski Options page starts here
?>

<?php if (isset($_POST['Submit'])) : ?>
	<div id="updated" class="updated fade">
		<p><?php _e('Tarski Options have been updated', 'tarski'); ?></p>
	</div>
<?php endif; ?>

<?php if(get_option('tarski_update_notification') == 'true') { ?>
<script src="http://tarskitheme.com/version.php?version=<?php echo $installedVersion; ?>" type="text/javascript"></script>
<?php } ?>

<div class="wrap"><h2><?php _e('Tarski Options', 'tarski'); ?></h2>
<form name="dofollow" action="" method="post">

	<input type="hidden" name="action" value="<?php tarskiupdate(); ?>" />
	<input type="hidden" name="page_options" value="'dofollow_timeout'" />
	
	<table width="100%" cellspacing="2" cellpadding="5" class="editform">

		<tr valign="top">
			<th scope="row"><?php _e('Update Notification', 'tarski'); ?></th>
			<td>
				<?php if(get_option('tarski_update_notification') == 'true') { ?>
				<?php _e('Tarski is set to notify you when an update is available.', 'tarski'); ?>  <input type="submit" name="tarski_update_notification" value="Turn update notification off?" />
				<?php } else { ?>
				<?php _e('Tarski can notify you when an update is available.  This involves sending a request to our server, so it is disabled by default.', 'tarski'); ?>  <input type="submit" name="tarski_update_notification" value="Turn update notification on?" />
				<?php } ?>
			</td>
		</tr>

<?php if(!tarski_checkForStaticPage('About') || !tarski_checkForStaticPage('Archives') || !tarski_checkForStaticPage('Tags')) { ?>
		<tr valign="top">
			<th scope="row"><?php _e('Initial Setup', 'tarski'); ?></th>
			<td>
				<?php if(!tarski_checkForStaticPage('About')) { ?>
					<input type="checkbox" name="create_page[]" value="about" /> <?php _e('Create an &#8216;About&#8217; page', 'tarski'); ?><br />
				<?php } ?>
				<?php if(!tarski_checkForStaticPage('Archives')) { ?>
					<input type="checkbox" name="create_page[]" value="archives" /> <?php _e('Create an &#8216;Archives&#8217; page', 'tarski'); ?><br />
				<?php } ?>
				<?php if(!tarski_checkForStaticPage('Tags')) { ?>
					<input type="checkbox" name="create_page[]" value="tags" /> <?php _e('Create a &#8216;Tags&#8217; page', 'tarski'); ?><br />
				<?php } ?>
				<p><small><?php _e('You&#8217;ll need to ', 'tarski'); ?><a href="options-permalink.php"><?php _e('update your permalink structure', 'tarski'); ?></a><?php _e(' after Tarski creates these pages for this to work.', 'tarski'); ?></small></p>
			</td>
		</tr>
<?php } ?>
		
		<tr valign="top">
			<th scope="row"><?php _e('About Text', 'tarski'); ?></th>
			<td>
				<label for="about_text">
				<textarea name="about_text" style="width: 98%;" rows="5" id="about_text"><?php echo stripslashes(get_option('blurb')); ?></textarea>
				<p><small><?php _e('Write a paragraph about yourself here, and it&#8217;ll show up in the footer. Deleting the content disables it.', 'tarski'); ?></small></p>
				</label>
			</td>
		</tr>

		<tr valign="top">
			<th scope="row"><?php echo __('Sidebar Contents'); ?></th>
			<td>
				<input type="hidden" name="sidebar[pages]" value="0" />
				<input type="checkbox" name="sidebar[pages]" value="1" <?php if(get_option('tarski_sidebar_pages')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Pages list', 'tarski'); ?><br />
				
<?php if(function_exists('blc_latest_comments')) { ?>
				<input type="hidden" name="sidebar[comments]" value="0" />
				<input type="checkbox" name="sidebar[comments]" value="1" <?php if(get_option('tarski_sidebar_comments')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Latest comments', 'tarski'); ?><br />
<?php } ?>
				
				<input type="hidden" name="sidebar[links]" value="0" />
				<input type="checkbox" name="sidebar[links]" value="1" <?php if(get_option('tarski_sidebar_links')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Links list', 'tarski'); ?><br />
				
				<textarea name="sidebar[custom]" style="width: 98%;" rows="5" id="sidebar_custom"><?php echo stripslashes(htmlspecialchars(get_option('tarski_sidebar_custom'))); ?></textarea>
				<p><small><?php _e('Anything you put into this custom content area, like text, images etc. will show up in the sidebar on the left. If you don&#8217;t want anything there, leave it blank!', 'tarski'); ?></small></p>
				
				<input type="hidden" name="sidebar[onlyhome]" value="0" />
				<input type="checkbox" name="sidebar[onlyhome]" value="1" <?php if(get_option('tarski_sidebar_onlyhome')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Only display the sidebar on the home page <small>(good for people with long sidebars'); ?></small><br />
			</td>
		</tr>

			<tr valign="top">
				<th scope="row"><?php _e('Asides Category', 'tarski'); ?></th>
				<td>
					<label for="asides_category">
			<?php
			global $wpdb;
			$id = get_option('tarski_asidescategory');
			if ($id != 0) {
			$asides_title = $wpdb->get_var("SELECT cat_name from $wpdb->categories WHERE cat_ID = $id");
			} else {
				$asides_title='DISABLE ASIDES';
				}
			$asides_cats = $wpdb->get_results("SELECT * from $wpdb->categories");
			?>
					<select name="asides_category" id="asides_category">
						<option value="<?php echo get_option('tarski_asidescategory'); ?>"><?php echo $asides_title; ?></option>
						<option value="-----">----</option>
						<option value="0"><?php _e('DISABLE ASIDES', 'tarski'); ?></option>
			<?php
			if($asides_cats) {
				foreach ($asides_cats as $cat) {
					echo '					<option value="' . $cat->cat_ID . '">' . $cat->cat_name . '</option>';
				}
			}
			?>
					</select>
				</label>
				<p><small><?php _e('Select a posts category to use for ', 'tarski'); ?><a href="http://photomatt.net/2004/05/19/asides/"><?php _e('Matt&#8217;s Asides technique', 'tarski'); ?></a><?php _e(' if you like.', 'tarski'); ?></small></p>
			</td>
		</tr>

		<tr valign="top">
			<th scope="row"><?php _e('Alternate Styles', 'tarski'); ?></th>
			<td>
				<label for="alternate_style">
					<?php
					global $wpdb;
					$name = get_option('tarski_style');
					
					$style_dir = @ dir(TEMPLATEPATH . '/styles');
					
					if ($style_dir) {
						while(($file = $style_dir->read()) !== false) {
								if (!preg_match('|^\.+$|', $file) && preg_match('@.(css)$@', $file)) 
								$styles[] = $file;
							}
						}
						
						if ($style_dir || $styles) {
							echo "<select name=\"alternate_style\" id=\"alternate_style\">\n";
							echo "<option value=\"$name\">";
							if($name) {
								echo $name;
							} else {
								echo "Default Style";
							}
							echo "</option>\n";
							echo "<option value=\"\">----</option>\n";
							echo "<option value=\"\">Default Style</option>\n";
							$count = 0;
							if($styles) {
								foreach($styles as $style) {
									$count++;
									echo "<option value=\"$style\">$style</option>\n";
								}
							}
							echo "</select>\n";
						}
					?>
				<p><small><?php _e('Tarski lets you choose an alternate style that modifies the default one. Pick from the list above, or even upload your own to ', 'tarski'); echo '<code>wp-content/themes/' . get_template() . '/styles/</code>'; _e('.', 'tarski'); ?></small></p>
				</label>
			</td>
		</tr>

		<tr valign="top">
			<th scope="row"><?php _e('Header Image', 'Tarski'); ?></th>
			<td>
				<label for="header_image">
					<?php
					global $wpdb;
					$name = get_option('tarski_header');
					
					$header_dir = @ dir(TEMPLATEPATH . '/headers');
					
					if ($header_dir) {
						while(($file = $header_dir->read()) !== false) {
								if (!preg_match('|^\.+$|', $file) && preg_match('@\-thumb.(jpg|png|gif)$@', $file)) 
								$header_images[] = $file;
							}
						}
						if ($header_dir || $header_images) {
							$count = 0;
							foreach($header_images as $header_image) {
								$count++;
								echo '<img class="header_image" style="padding: 5px;';
								if(str_replace("-thumb", "", $header_image) == get_option('tarski_header')) {
									echo " background-color: $highlightColor;";
								}
								echo '" id="img' . $count . '" src="' . get_settings('siteurl') . "/wp-content/themes/" . get_template() . '/headers/' . $header_image . '" onclick="$(\'header_image\').value = \'' . $header_image . "'; new Effect.Highlight(this, {duration: 2.0, startcolor: '#ffffff', endcolor: '$highlightColor', restorecolor: '$highlightColor', beforeStart: function() { a = document.getElementsByClassName('header_image'); for(i = 0; i < a.length; i++) { a[i].style.backgroundColor = '#ffffff' }}});\" />" . "\n";
						}
					}
					?>
					<input type="hidden" name="header_image" id="header_image" value="<?php echo stripslashes(get_option('tarski_header')); ?>" />
				<p><small><?php _e('Choose a header image by clicking on it. The current image is the ', 'tarski'); ?><span style="padding: 2px; border: 5px solid <?php echo $highlightColor; ?>;"><?php _e('highlighted one', 'tarski'); ?></span><?php _e('.', 'tarski'); ?></small></p>
				</label>
			</td>
		</tr>


		<tr valign="top">
			<th scope="row"><?php _e('Navigation Display', 'tarski'); ?></th>
			<td>
				<?php
				
				global $wpdb;
				$results = $wpdb->get_results("SELECT ID, post_title from $wpdb->posts WHERE post_status='static' ORDER BY post_parent, menu_order");
				
				$nav_pages = explode(',', get_option('tarski_nav_pages'));
				
				if($results) {
					foreach($results as $page) {
						echo '<input type="checkbox" name="nav_pages[]" value="' . $page->ID . '"';
						if(in_array($page->ID, $nav_pages)) { echo ' checked="checked"'; }
						echo ' /> <a href="' . get_permalink($page->ID) . '">' . $page->post_title . '</a><br />';
					}
				}
				
				?>
			</td>
		</tr>


		<tr valign="top">
			<th scope="row"><?php echo __('Miscellaneous Options'); ?></th>
			<td>
				<input type="hidden" name="display_title" value="lolno">
				<input type="checkbox" name="display_title" value="1" <?php if(get_option('tarski_display_title') != 'lolno') { echo "checked=\"checked\" "; } ?>/> <?php _e('Display site title', 'tarski'); ?><br />

				<input type="hidden" name="display_tagline" value="0">
				<input type="checkbox" name="display_tagline" value="1" <?php if(get_option('tarski_display_tagline')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Display site tagline', 'tarski'); ?><br />
				
				<input type="hidden" name="hide_categories" value="0">
				<input type="checkbox" name="hide_categories" value="1" <?php if(get_option('tarski_hide_categories')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Hide post categories', 'tarski'); ?><br />

				<input type="hidden" name="use_pages" value="0">
				<input type="checkbox" name="use_pages" value="1" <?php if(get_option('tarski_use_pages')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Paginate index pages ', 'tarski'); ?><small><?php _e('(such as the front page, or search results)', 'tarski'); ?></small><br />
				
				<input type="hidden" name="centered_theme" value="0">
				<input type="checkbox" name="centered_theme" value="1" <?php if(get_option('tarski_centered_theme')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Centered version of theme', 'tarski'); ?><br />
				
				<input type="hidden" name="ajax_tags" value="0">
				<input type="checkbox" name="ajax_tags" value="1" <?php if(get_option('tarski_ajax_tags')) { echo "checked=\"checked\" "; } ?>/> <?php _e('AJAX tag search ', 'tarski'); ?><small><?php _e('(requires UTW 3.1 or higher)', 'tarski'); ?></small><br />

				<input type="hidden" name="swap_sides" value="0">
				<input type="checkbox" name="swap_sides" value="1" <?php if(get_option('tarski_swap_sides')) { echo "checked=\"checked\" "; } ?>/> <?php _e('Swap the content and sidebar positions ', 'tarski'); ?><small><?php _e('(this will also swap comments, navigation and footer content)', 'tarski'); ?></small><br />

			</td>
		</tr>

	</table>

	<p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options', 'tarski') ?> &raquo;" /></p>

</form>
</div>

<div class="wrap">
	<p style="text-align: center;"><?php _e('The ', 'tarski'); ?><a href="http://tarskitheme.com/help/"><?php _e('Tarski documentation', 'tarski'); ?></a><?php _e(' is full of useful stuff', 'tarski'); ?> &middot; <a href="http://tarskitheme.com/credits/"><?php _e('Credits &amp; Thanks', 'tarski'); ?></a></p>
</div>

<?php }

function tarski_get_output($code) {
	ob_start();
	eval($code);
	$return = ob_get_contents();
	ob_end_clean();
	return $return;
}

// tarski_excerpt shamelessly borrowed from http://guff.szub.net/2005/02/26/the-excerpt-reloaded/
function tarski_excerpt($excerpt_length = 120, $allowedtags = '', $filter_type = 'none', $use_more_link = 1, $more_link_text = '(more...)', $force_more = 1, $fakeit = 1, $no_more = 0, $more_tag = 'div', $more_link_title = 'Continue reading this entry', $showdots = 1) {
	global $post;

	if (!empty($post->post_password)) { // if there's a password
		if ($_COOKIE['wp-postpass_'.COOKIEHASH] != $post->post_password) { // and it doesn't match cookie
			if(is_feed()) { // if this runs in a feed
				$output = __('There is no excerpt because this is a protected post.');
			} else {
				$output = get_the_password_form();
			}
		}
		return $output;
	}

	if($fakeit == 2) { // force content as excerpt
		$text = $post->post_content;
	} elseif($fakeit == 1) { // content as excerpt, if no excerpt
		$text = (empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { // excerpt no matter what
		$text = $post->post_excerpt;
	}

	if($excerpt_length < 0) {
		$output = $text;
	} else {
	if(!$no_more && strpos($text, '<!--more-->')) {
		$text = explode('<!--more-->', $text, 2);
			$l = count($text[0]);
			$more_link = 1;
		} else {
			$text = explode(' ', $text);
			if(count($text) > $excerpt_length) {
				$l = $excerpt_length;
				$ellipsis = 1;
			} else {
				$l = count($text);
				$more_link_text = '';
				$ellipsis = 0;
			}
		}
		for ($i=0; $i<$l; $i++)
			$output .= $text[$i] . ' ';
	}

	if('all' != $allowed_tags) {
		$output = strip_tags($output, $allowedtags);
	}

	$output = rtrim($output, "\s\n\t\r\0\x0B");
	$output = ($fix_tags) ? $output : balanceTags($output);
	$output .= ($showdots && $ellipsis) ? '...' : '';

	switch($more_tag) {
		case('div') :
			$tag = 'div';
			break;
		case('span') :
			$tag = 'span';
			break;
		case('p') :
			$tag = 'p';
			break;
		default :
			$tag = 'span';
			break;
	}

	if ($use_more_link && $more_link_text) {
		if($force_more) {
			$output .= ' <' . $tag . ' class="more-link"><a href="'. get_permalink($post->ID) . '#more-' . $post->ID .'" title="' . $more_link_title . '">' . $more_link_text . '</a></' . $tag . '>' . "\n";
		} else {
			$output .= ' <' . $tag . ' class="more-link"><a href="'. get_permalink($post->ID) . '" title="' . $more_link_title . '">' . $more_link_text . '</a></' . $tag . '>' . "\n";
		}
	}

	$output = apply_filters($filter_type, $output);
	return $output;
}

// Tarski Options page ends here ?>